# PyEEM

![Test](https://github.com/drewmee/PyEEM/workflows/Test/badge.svg)
[![Read the Docs](https://readthedocs.org/projects/pyeem/badge/?version=latest)](https://pyeem.readthedocs.io/)
[![PyPi version](https://img.shields.io/pypi/v/pyeem.svg 'pypi version')](https://pypi.org/project/pyeem/)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pyeem.svg)](https://pypi.org/project/pyeem/)
[![Binder](https://mybinder.org/badge.svg)](https://mybinder.org/v2/gh/drewmee/PyEEM/master?filepath=docs%2Fsource%2Ftutorials%2Fnotebooks)
[![License](https://img.shields.io/github/license/mashape/apistatus.svg)](https://github.com/drewmee/PyEEM/blob/master/LICENSE)
[![Code style](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
<!--- Badge for codecov -->

Python library for the preprocessing, analysis, and visualization of Excitation Emission Matrices (EEMs).

## Installation

Install via pip:

    $ pip install pyeem [--upgrade]

## Documentation

  Full documentation can be found [here](https://pyeem.readthedocs.io/).

## Dependencies for Local Development

If you wish to build the local documentation or run unit tests, there are a few additional dependencies. Those can be installed by:

pip install -e ".[docs, tests]"

## License

This library is licensed under the MIT license. The full text of the license can be found in this repository at LICENSE.txt.